summaryrefslogtreecommitdiffhomepage
path: root/Opcode/OPC_TreeBuilders.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Opcode/OPC_TreeBuilders.cpp')
-rw-r--r--Opcode/OPC_TreeBuilders.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/Opcode/OPC_TreeBuilders.cpp b/Opcode/OPC_TreeBuilders.cpp
index 73e89c7..cd20c80 100644
--- a/Opcode/OPC_TreeBuilders.cpp
+++ b/Opcode/OPC_TreeBuilders.cpp
@@ -91,7 +91,7 @@ bool AABBTreeOfAABBsBuilder::ComputeGlobalBox(const udword* primitives, udword n
float AABBTreeOfAABBsBuilder::GetSplittingValue(udword index, udword axis) const
{
// For an AABB, the splitting value is the middle of the given axis,
// i.e. the corresponding component of the center point
return mAABBArray[index].GetCenter(axis);
}
@@ -110,8 +110,8 @@ bool AABBTreeOfTrianglesBuilder::ComputeGlobalBox(const udword* primitives, udwo
if(!primitives || !nb_prims) return false;
// Initialize global box
- Point Min(MAX_FLOAT, MAX_FLOAT, MAX_FLOAT);
- Point Max(MIN_FLOAT, MIN_FLOAT, MIN_FLOAT);
+ IcePoint Min(MAX_FLOAT, MAX_FLOAT, MAX_FLOAT);
+ IcePoint Max(MIN_FLOAT, MIN_FLOAT, MIN_FLOAT);
// Loop through triangles
VertexPointers VP;
@@ -138,7 +138,7 @@ bool AABBTreeOfTrianglesBuilder::ComputeGlobalBox(const udword* primitives, udwo
float AABBTreeOfTrianglesBuilder::GetSplittingValue(udword index, udword axis) const
{
/* // Compute center of triangle
- Point Center;
+ IcePoint Center;
mTriList[index].Center(mVerts, Center);
// Return value
return Center[axis];*/
@@ -91,7 +91,7 @@ bool AABBTreeOfAABBsBuilder::ComputeGlobalBox(const udword* primitives, udword n
{
// For an AABB, the splitting value is the middle of the given axis,
- // i.e. the corresponding component of the center point
+ // i.e. the corresponding component of the center IcePoint
return mAABBArray[index].GetCenter(axis);
}